==> bbwa-0.0.4.tar.gz: bbwa-0.0.4/top.php <==
<?php
//
// BBWA
// top.php
// ե졼
// Teppei KAKU <teppei@sat.co.jp>
//
?>


<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=euc-jp">
<link rel="stylesheet" type="text/css" href="default.css">
<script language="JavaScript">
<!--
var order = 0;
var THUMB

function sortSelect(sf) {
  if (sf.ss.selectedIndex == 0) {
    order = 0;
    parent.LEFT.location.href = 'left.php?page=1&order=0';
    parent.RIGHT.location.href = 'right.php';
  } else if (sf.ss.selectedIndex == 1) {
    order = 1;
    parent.LEFT.location.href = 'left.php?page=1&order=1';
    parent.RIGHT.location.href = 'right.php';
  } else if (sf.ss.selectedIndex == 2) {
    order = 2;
    parent.LEFT.location.href = 'left.php?page=1&order=2';
    parent.RIGHT.location.href = 'right.php';
  }
  if(THUMB && !(THUMB.closed)) {
    THUMB.location.href = 'thumb.php?page=1&order=' + order;
  }
  parent.LEFT.focus();
}

function openWindow(urlString, width) {
  if (!THUMB || THUMB.closed) {
    var trueUrl = urlString + order;
    var trueWidth = Math.min((width + 25) * 5, screen.width * 0.9);
    var arg = "toolbar=no,location=no,directories=no,status=no,menubar=no,scrollbars=yes,resizable=yes,width=" + trueWidth + ",height=" + (screen.height * 0.7);
    THUMB = window.open(trueUrl, "THUMB", arg);
  } else {
    THUMB.focus();
  }
}

function openNew() {
  var arg = "right.php?new=1&order=" + order;
  parent.RIGHT.location.href = arg;
}
//-->
</script>
</head>
<body class="top">
<table border="0" width="100%" class="top"
  cellspacing="0" cellpadding="0">
<tr><td nowrap>
<form class="top">
¤ؤ
<select class="top" name="ss" align="absmiddle"
  onChange="sortSelect(this.form)">
<option>ͥ
<option>ͥ
<option>ͥ(Ť)
</select>
&nbsp;&nbsp;


<?php
include("variables.php");
print("<a href=\"${homeUrl}\" target=\"_top\">");
?>


<img src="Icons/icon_home.png" border="0" align="absmiddle">ۡ</a>
&nbsp;&nbsp;
<a href="JavaScript:openNew()">
<img src="Icons/icon_new.png" border="0" align="absmiddle"></a>
&nbsp;&nbsp;
<a href="help.html" target="RIGHT">
<img src="Icons/icon_help.png" border="0" align="absmiddle">إ</a>
&nbsp;&nbsp;


<?php
print("<a href=\"JavaScript:openWindow('thumb.php?page=1&order=', ${thumbSize})\">");
?>


<img src="Icons/icon_thumb.png" border="0" align="absmiddle"></a>
</form>
</td>
<td nowrap align="right">
<strong><a href="http://bbwa.sourceforge.jp/" target="_blank">
BBWA-0.0.4
</a></strong>
</td></tr>
</table>
</body>
</html>

==> bbwa-0.0.5.tar.gz: bbwa-0.0.5/top.php <==
<?php
//
// BBWA
// top.php
// ե졼
// Teppei KAKU <teppei@sat.co.jp>
//

include("variables.php");
?>


<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=euc-jp">


<?php
print("<link rel=\"stylesheet\" type=\"text/css\" href=\"Themes/${theme}.css\">");
?>


<script language="JavaScript">
<!--
var THUMB

function sortSelect(sf) {
  if (sf.ss.selectedIndex == 0) {
    parent.LEFT.location.href = 'left.php?page=1&order=0';
  } else if (sf.ss.selectedIndex == 1) {
    parent.LEFT.location.href = 'left.php?page=1&order=1';
  } else if (sf.ss.selectedIndex == 2) {
    parent.LEFT.location.href = 'left.php?page=1&order=2';
  }
  parent.LEFT.focus();
}

function openWindow(urlString) {
  if (!THUMB || THUMB.closed) {
    var arg = "toolbar=no,location=no,directories=no,status=no,menubar=no,scrollbars=yes,resizable=yes";
    THUMB = window.open(urlString, "THUMB", arg);
  } else {
    THUMB.focus();
  }
}
//-->
</script>
</head>
<body class="top">
<table border="0" width="100%" class="top"
  cellspacing="0" cellpadding="0">
<tr><td nowrap>
<form class="top" name="sf">
¤ؤ
<select class="top" name="ss" align="absmiddle"
  onChange="sortSelect(this.form)">
<option>ͥ
<option>ͥ
<option>ͥ(Ť)
</select>
&nbsp;&nbsp;


<?php
print("<a href=\"${homeUrl}\" target=\"_top\">");
?>


<img src="Icons/icon_home.png" border="0" align="absmiddle">ۡ</a>
&nbsp;&nbsp;
<a href="right.php?new=1" target="RIGHT">
<img src="Icons/icon_new.png" border="0" align="absmiddle"></a>
&nbsp;&nbsp;
<a href="help.php" target="RIGHT">
<img src="Icons/icon_help.png" border="0" align="absmiddle">إ</a>
&nbsp;&nbsp;
<a href="JavaScript:openWindow('thumb.php?order=0')">
<img src="Icons/icon_thumb.png" border="0" align="absmiddle"></a>
</form>
</td>
<td nowrap align="right">
<strong><a href="http://bbwa.sourceforge.jp/" target="_blank">
BBWA-0.0.5
</a></strong>
</td></tr>
</table>
</body>
</html>
